% FORMULA DEI TRAPEZI COMPOSTA PER IL CALCOLO APPROSSIMATO DI INTEGRALI
%
% function I = ctrap(funz,a,b,n)
%
% DATI DI INPUT:
%  funz = stringa contenente il nome della funzione integranda
%         (definita in un omonimo file .m)
%     a = estremo inferiore dell'intervallo di integrazione
%     b = estremo superiore dell'intervallo di integrazione
%     n = numero di sottointervalli a cui applicare la formula dei trapezi
%
% DATI DI OUTPUT:
%     I = approssimazione dell'integrale
%

function I = ctrap(funz,a,b,n)
h = (b-a)/n;
x = a + [0:n]*h;
I = (feval(funz,x(1)) + 2*sum(feval(funz,x(2:n))) + feval(funz,x(n+1))) * h/2;

